# Generated by Django 3.1.6 on 2021-04-22 14:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('ehf_invoice', '0002_related_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='invoice',
            name='credit',
            field=models.BooleanField(default=False, verbose_name='kreditnota'),
        ),
    ]



from django.contrib.auth.decorators import permission_required
from django.shortcuts import render

from ehf_invoice.models import Invoice, SerialNumber, Supplier


@permission_required('ehf_invoice.view_supplier', raise_exception=True)
def show_supplier(request, supplier):
    supplier = Supplier.objects.get(id=supplier)
    return render(request, 'ehf_invoice/supplier.html', {'supplier': supplier})


@permission_required('ehf_invoice.view_invoice', raise_exception=True)
def show_invoice(request, invoice_number=None):
    if not invoice_number:
        if request.GET.get('id'):
            invoice = Invoice.objects.get(id=request.GET.get('id'))
        else:
            raise ValueError('No invoice identifier set')
    else:
        invoice = Invoice.objects.get(invoice_number=invoice_number)
    return render(request, 'ehf_invoice/invoice.html', {'invoice': invoice})


@permission_required('ehf_invoice.view_serialnumber', raise_exception=True)
def find_serial(request, serial_number):
    serial = SerialNumber.objects.get(serial=serial_number)
    invoice = serial.line.invoice
    return render(request, 'ehf_invoice/invoice.html', {'invoice': invoice})



# Generated by Django 3.1.5 on 2021-03-08 18:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('ehf_invoice', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='invoice',
            name='customer',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='invoices', to='ehf_invoice.customer', verbose_name='kunde'),
        ),
        migrations.AlterField(
            model_name='invoice',
            name='supplier',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='invoices', to='ehf_invoice.supplier', verbose_name='leverandør'),
        ),
    ]
